/********************************************************************************
** Form generated from reading UI file 'compositing.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COMPOSITING_H
#define UI_COMPOSITING_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kmessagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_CompositingForm
{
public:
    QFormLayout *formLayout;
    QVBoxLayout *verticalLayout_4;
    KMessageWidget *glCrashedWarning;
    KMessageWidget *windowThumbnailWarning;
    QLabel *compositingLabel;
    QCheckBox *kcfg_Enabled;
    QCheckBox *kcfg_WindowsBlockCompositing;
    QLabel *animationSpeedLabel;
    QWidget *animationSpeedControls;
    QVBoxLayout *verticalLayout;
    QSlider *animationDurationFactor;
    QHBoxLayout *_3;
    QLabel *label_3;
    QSpacerItem *horizontalSpacer;
    QLabel *label;
    QLabel *label_HiddenPreviews;
    QComboBox *kcfg_HiddenPreviews;

    void setupUi(QWidget *CompositingForm)
    {
        if (CompositingForm->objectName().isEmpty())
            CompositingForm->setObjectName("CompositingForm");
        CompositingForm->resize(526, 395);
        formLayout = new QFormLayout(CompositingForm);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        formLayout->setLabelAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        verticalLayout_4 = new QVBoxLayout();
        verticalLayout_4->setObjectName("verticalLayout_4");
        glCrashedWarning = new KMessageWidget(CompositingForm);
        glCrashedWarning->setObjectName("glCrashedWarning");
        glCrashedWarning->setVisible(false);
        glCrashedWarning->setWordWrap(true);
        QIcon icon(QIcon::fromTheme(QIcon::ThemeIcon::DialogWarning));
        glCrashedWarning->setIcon(icon);

        verticalLayout_4->addWidget(glCrashedWarning);

        windowThumbnailWarning = new KMessageWidget(CompositingForm);
        windowThumbnailWarning->setObjectName("windowThumbnailWarning");
        windowThumbnailWarning->setVisible(false);
        windowThumbnailWarning->setWordWrap(true);
        windowThumbnailWarning->setIcon(icon);

        verticalLayout_4->addWidget(windowThumbnailWarning);


        formLayout->setLayout(0, QFormLayout::ItemRole::SpanningRole, verticalLayout_4);

        compositingLabel = new QLabel(CompositingForm);
        compositingLabel->setObjectName("compositingLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, compositingLabel);

        kcfg_Enabled = new QCheckBox(CompositingForm);
        kcfg_Enabled->setObjectName("kcfg_Enabled");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_Enabled);

        kcfg_WindowsBlockCompositing = new QCheckBox(CompositingForm);
        kcfg_WindowsBlockCompositing->setObjectName("kcfg_WindowsBlockCompositing");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_WindowsBlockCompositing);

        animationSpeedLabel = new QLabel(CompositingForm);
        animationSpeedLabel->setObjectName("animationSpeedLabel");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, animationSpeedLabel);

        animationSpeedControls = new QWidget(CompositingForm);
        animationSpeedControls->setObjectName("animationSpeedControls");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(animationSpeedControls->sizePolicy().hasHeightForWidth());
        animationSpeedControls->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(animationSpeedControls);
        verticalLayout->setObjectName("verticalLayout");
        animationDurationFactor = new QSlider(animationSpeedControls);
        animationDurationFactor->setObjectName("animationDurationFactor");
        animationDurationFactor->setMinimum(0);
        animationDurationFactor->setMaximum(0);
        animationDurationFactor->setOrientation(Qt::Horizontal);
        animationDurationFactor->setTickPosition(QSlider::TicksBelow);
        animationDurationFactor->setTickInterval(1);

        verticalLayout->addWidget(animationDurationFactor);

        _3 = new QHBoxLayout();
        _3->setObjectName("_3");
        label_3 = new QLabel(animationSpeedControls);
        label_3->setObjectName("label_3");

        _3->addWidget(label_3);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        _3->addItem(horizontalSpacer);

        label = new QLabel(animationSpeedControls);
        label->setObjectName("label");

        _3->addWidget(label);


        verticalLayout->addLayout(_3);


        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, animationSpeedControls);

        label_HiddenPreviews = new QLabel(CompositingForm);
        label_HiddenPreviews->setObjectName("label_HiddenPreviews");

        formLayout->setWidget(13, QFormLayout::ItemRole::LabelRole, label_HiddenPreviews);

        kcfg_HiddenPreviews = new QComboBox(CompositingForm);
        kcfg_HiddenPreviews->addItem(QString());
        kcfg_HiddenPreviews->addItem(QString());
        kcfg_HiddenPreviews->addItem(QString());
        kcfg_HiddenPreviews->setObjectName("kcfg_HiddenPreviews");

        formLayout->setWidget(13, QFormLayout::ItemRole::FieldRole, kcfg_HiddenPreviews);


        retranslateUi(CompositingForm);

        QMetaObject::connectSlotsByName(CompositingForm);
    } // setupUi

    void retranslateUi(QWidget *CompositingForm)
    {
        glCrashedWarning->setText(tr2i18n("OpenGL compositing (the default) has crashed KWin in the past.\n"
"This was most likely due to a driver bug.\n"
"If you think that you have meanwhile upgraded to a stable driver,\n"
"you can reset this protection but be aware that this might result in an immediate crash!", nullptr));
        windowThumbnailWarning->setText(tr2i18n("Keeping the window thumbnail always interferes with the minimized state of windows. This can result in windows not suspending their work when minimized.", nullptr));
        compositingLabel->setText(tr2i18n("Compositing:", nullptr));
        kcfg_Enabled->setText(tr2i18n("Enable on startup", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_WindowsBlockCompositing->setToolTip(tr2i18n("Applications can set a hint to block compositing when the window is open.\n"
" This brings performance improvements for e.g. games.\n"
" The setting can be overruled by window-specific rules.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_WindowsBlockCompositing->setText(tr2i18n("Allow applications to block compositing", nullptr));
        animationSpeedLabel->setText(tr2i18n("Animation speed:", nullptr));
        label_3->setText(tr2i18n("Very slow", nullptr));
        label->setText(tr2i18n("Instant", nullptr));
        label_HiddenPreviews->setText(tr2i18n("Keep window thumbnails:", nullptr));
        kcfg_HiddenPreviews->setItemText(0, tr2i18n("Never", nullptr));
        kcfg_HiddenPreviews->setItemText(1, tr2i18n("Only for Shown Windows", nullptr));
        kcfg_HiddenPreviews->setItemText(2, tr2i18n("Always", nullptr));

        (void)CompositingForm;
    } // retranslateUi

};

namespace Ui {
    class CompositingForm: public Ui_CompositingForm {};
} // namespace Ui

QT_END_NAMESPACE

#endif // COMPOSITING_H

