// This file is generated by kconfig_compiler_kf6 from kwinoptions_kdeglobals_settings.kcfg.
// All changes you do to this file will be lost.

#include "kwinoptions_kdeglobals_settings.h"

KWinOptionsKDEGlobalsSettings::KWinOptionsKDEGlobalsSettings( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "kdeglobals" ) )
{
  setParent(parent);
  setCurrentGroup( QStringLiteral( "General" ) );

  KConfigSkeleton::ItemBool  *itemAllowKDEAppsToRememberWindowPositions;
  itemAllowKDEAppsToRememberWindowPositions = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AllowKDEAppsToRememberWindowPositions" ), mAllowKDEAppsToRememberWindowPositions, true );
  addItem( itemAllowKDEAppsToRememberWindowPositions, QStringLiteral( "AllowKDEAppsToRememberWindowPositions" ) );
}

bool KWinOptionsKDEGlobalsSettings::defaultAllowKDEAppsToRememberWindowPositionsValue_helper() const
{

  return true;
}

KWinOptionsKDEGlobalsSettings::~KWinOptionsKDEGlobalsSettings()
{
}

