/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kwin.Compositing.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "compositingadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class CompositingAdaptor
 */

CompositingAdaptor::CompositingAdaptor(KWin::CompositorDBusInterface *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

CompositingAdaptor::~CompositingAdaptor()
{
    // destructor
}

bool CompositingAdaptor::active() const
{
    // get the value of property active
    return qvariant_cast< bool >(parent()->property("active"));
}

QString CompositingAdaptor::compositingNotPossibleReason() const
{
    // get the value of property compositingNotPossibleReason
    return qvariant_cast< QString >(parent()->property("compositingNotPossibleReason"));
}

bool CompositingAdaptor::compositingPossible() const
{
    // get the value of property compositingPossible
    return qvariant_cast< bool >(parent()->property("compositingPossible"));
}

QString CompositingAdaptor::compositingType() const
{
    // get the value of property compositingType
    return qvariant_cast< QString >(parent()->property("compositingType"));
}

bool CompositingAdaptor::openGLIsBroken() const
{
    // get the value of property openGLIsBroken
    return qvariant_cast< bool >(parent()->property("openGLIsBroken"));
}

bool CompositingAdaptor::platformRequiresCompositing() const
{
    // get the value of property platformRequiresCompositing
    return qvariant_cast< bool >(parent()->property("platformRequiresCompositing"));
}

QStringList CompositingAdaptor::supportedOpenGLPlatformInterfaces() const
{
    // get the value of property supportedOpenGLPlatformInterfaces
    return qvariant_cast< QStringList >(parent()->property("supportedOpenGLPlatformInterfaces"));
}


#include "moc_compositingadaptor.cpp"
