/* Generated by wayland-scanner 1.25.0 */

#ifndef BLUR_SERVER_PROTOCOL_H
#define BLUR_SERVER_PROTOCOL_H

#include <stdint.h>
#include <stddef.h>
#include "wayland-server.h"

#ifdef  __cplusplus
extern "C" {
#endif

struct wl_client;
struct wl_resource;

/**
 * @page page_blur The blur protocol
 * @section page_ifaces_blur Interfaces
 * - @subpage page_iface_org_kde_kwin_blur_manager - 
 * - @subpage page_iface_org_kde_kwin_blur - 
 * @section page_copyright_blur Copyright
 * <pre>
 *
 * SPDX-FileCopyrightText: 2015 Martin Gräßlin
 * SPDX-FileCopyrightText: 2015 Marco Martin
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 * </pre>
 */
struct org_kde_kwin_blur;
struct org_kde_kwin_blur_manager;
struct wl_region;
struct wl_surface;

#ifndef ORG_KDE_KWIN_BLUR_MANAGER_INTERFACE
#define ORG_KDE_KWIN_BLUR_MANAGER_INTERFACE
/**
 * @page page_iface_org_kde_kwin_blur_manager org_kde_kwin_blur_manager
 * @section page_iface_org_kde_kwin_blur_manager_api API
 * See @ref iface_org_kde_kwin_blur_manager.
 */
/**
 * @defgroup iface_org_kde_kwin_blur_manager The org_kde_kwin_blur_manager interface
 */
extern const struct wl_interface org_kde_kwin_blur_manager_interface;
#endif
#ifndef ORG_KDE_KWIN_BLUR_INTERFACE
#define ORG_KDE_KWIN_BLUR_INTERFACE
/**
 * @page page_iface_org_kde_kwin_blur org_kde_kwin_blur
 * @section page_iface_org_kde_kwin_blur_api API
 * See @ref iface_org_kde_kwin_blur.
 */
/**
 * @defgroup iface_org_kde_kwin_blur The org_kde_kwin_blur interface
 */
extern const struct wl_interface org_kde_kwin_blur_interface;
#endif

/**
 * @ingroup iface_org_kde_kwin_blur_manager
 * @struct org_kde_kwin_blur_manager_interface
 */
struct org_kde_kwin_blur_manager_interface {
	/**
	 */
	void (*create)(struct wl_client *client,
		       struct wl_resource *resource,
		       uint32_t id,
		       struct wl_resource *surface);
	/**
	 */
	void (*unset)(struct wl_client *client,
		      struct wl_resource *resource,
		      struct wl_resource *surface);
};


/**
 * @ingroup iface_org_kde_kwin_blur_manager
 */
#define ORG_KDE_KWIN_BLUR_MANAGER_CREATE_SINCE_VERSION 1
/**
 * @ingroup iface_org_kde_kwin_blur_manager
 */
#define ORG_KDE_KWIN_BLUR_MANAGER_UNSET_SINCE_VERSION 1

/**
 * @ingroup iface_org_kde_kwin_blur
 * @struct org_kde_kwin_blur_interface
 */
struct org_kde_kwin_blur_interface {
	/**
	 */
	void (*commit)(struct wl_client *client,
		       struct wl_resource *resource);
	/**
	 */
	void (*set_region)(struct wl_client *client,
			   struct wl_resource *resource,
			   struct wl_resource *region);
	/**
	 * release the blur object
	 *
	 * 
	 */
	void (*release)(struct wl_client *client,
			struct wl_resource *resource);
};


/**
 * @ingroup iface_org_kde_kwin_blur
 */
#define ORG_KDE_KWIN_BLUR_COMMIT_SINCE_VERSION 1
/**
 * @ingroup iface_org_kde_kwin_blur
 */
#define ORG_KDE_KWIN_BLUR_SET_REGION_SINCE_VERSION 1
/**
 * @ingroup iface_org_kde_kwin_blur
 */
#define ORG_KDE_KWIN_BLUR_RELEASE_SINCE_VERSION 1

#ifdef  __cplusplus
}
#endif

#endif
