/****************************************************************************
** Meta object code from reading C++ file 'output.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kwin-x11-6.7.4/src/core/output.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'output.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4KWin6OutputE_t {};
} // unnamed namespace

template <> constexpr inline auto KWin::Output::qt_create_metaobjectdata<qt_meta_tag_ZN4KWin6OutputE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWin::Output",
        "geometryChanged",
        "",
        "enabledChanged",
        "scaleChanged",
        "aboutToTurnOff",
        "std::chrono::milliseconds",
        "time",
        "wakeUp",
        "aboutToChange",
        "OutputChangeSet*",
        "changeSet",
        "changed",
        "currentModeChanged",
        "modesChanged",
        "outputChange",
        "QRegion",
        "damagedRegion",
        "transformChanged",
        "dpmsModeChanged",
        "capabilitiesChanged",
        "overscanChanged",
        "vrrPolicyChanged",
        "rgbRangeChanged",
        "wideColorGamutChanged",
        "referenceLuminanceChanged",
        "highDynamicRangeChanged",
        "autoRotationPolicyChanged",
        "iccProfileChanged",
        "iccProfilePathChanged",
        "brightnessMetadataChanged",
        "sdrGamutWidenessChanged",
        "colorDescriptionChanged",
        "colorProfileSourceChanged",
        "brightnessChanged",
        "colorPowerTradeoffChanged",
        "dimmingChanged",
        "mapToGlobal",
        "QPointF",
        "pos",
        "mapFromGlobal",
        "geometry",
        "QRect",
        "devicePixelRatio",
        "name",
        "manufacturer",
        "model",
        "serialNumber",
        "DpmsMode",
        "On",
        "Standby",
        "Suspend",
        "Off",
        "AboutToTurnOff",
        "SubPixel",
        "Unknown",
        "None",
        "Horizontal_RGB",
        "Horizontal_BGR",
        "Vertical_RGB",
        "Vertical_BGR",
        "RgbRange",
        "Automatic",
        "Full",
        "Limited",
        "AutoRotationPolicy",
        "Never",
        "InTabletMode",
        "Always",
        "ColorPowerTradeoff",
        "PreferEfficiency",
        "PreferAccuracy"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'geometryChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scaleChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'aboutToTurnOff'
        QtMocHelpers::SignalData<void(std::chrono::milliseconds)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'wakeUp'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'aboutToChange'
        QtMocHelpers::SignalData<void(OutputChangeSet *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentModeChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modesChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputChange'
        QtMocHelpers::SignalData<void(const QRegion &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Signal 'transformChanged'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dpmsModeChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'capabilitiesChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'overscanChanged'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'vrrPolicyChanged'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rgbRangeChanged'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wideColorGamutChanged'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'referenceLuminanceChanged'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'highDynamicRangeChanged'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoRotationPolicyChanged'
        QtMocHelpers::SignalData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iccProfileChanged'
        QtMocHelpers::SignalData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iccProfilePathChanged'
        QtMocHelpers::SignalData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'brightnessMetadataChanged'
        QtMocHelpers::SignalData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sdrGamutWidenessChanged'
        QtMocHelpers::SignalData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorDescriptionChanged'
        QtMocHelpers::SignalData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorProfileSourceChanged'
        QtMocHelpers::SignalData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'brightnessChanged'
        QtMocHelpers::SignalData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorPowerTradeoffChanged'
        QtMocHelpers::SignalData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dimmingChanged'
        QtMocHelpers::SignalData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'mapToGlobal'
        QtMocHelpers::MethodData<QPointF(const QPointF &) const>(37, 2, QMC::AccessPublic, 0x80000000 | 38, {{
            { 0x80000000 | 38, 39 },
        }}),
        // Method 'mapFromGlobal'
        QtMocHelpers::MethodData<QPointF(const QPointF &) const>(40, 2, QMC::AccessPublic, 0x80000000 | 38, {{
            { 0x80000000 | 38, 39 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'geometry'
        QtMocHelpers::PropertyData<QRect>(41, 0x80000000 | 42, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'devicePixelRatio'
        QtMocHelpers::PropertyData<qreal>(43, QMetaType::QReal, QMC::DefaultPropertyFlags, 2),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(44, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'manufacturer'
        QtMocHelpers::PropertyData<QString>(45, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'model'
        QtMocHelpers::PropertyData<QString>(46, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'serialNumber'
        QtMocHelpers::PropertyData<QString>(47, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'DpmsMode'
        QtMocHelpers::EnumData<enum DpmsMode>(48, 48, QMC::EnumIsScoped).add({
            {   49, DpmsMode::On },
            {   50, DpmsMode::Standby },
            {   51, DpmsMode::Suspend },
            {   52, DpmsMode::Off },
            {   53, DpmsMode::AboutToTurnOff },
        }),
        // enum 'SubPixel'
        QtMocHelpers::EnumData<enum SubPixel>(54, 54, QMC::EnumIsScoped).add({
            {   55, SubPixel::Unknown },
            {   56, SubPixel::None },
            {   57, SubPixel::Horizontal_RGB },
            {   58, SubPixel::Horizontal_BGR },
            {   59, SubPixel::Vertical_RGB },
            {   60, SubPixel::Vertical_BGR },
        }),
        // enum 'RgbRange'
        QtMocHelpers::EnumData<enum RgbRange>(61, 61, QMC::EnumIsScoped).add({
            {   62, RgbRange::Automatic },
            {   63, RgbRange::Full },
            {   64, RgbRange::Limited },
        }),
        // enum 'AutoRotationPolicy'
        QtMocHelpers::EnumData<enum AutoRotationPolicy>(65, 65, QMC::EnumIsScoped).add({
            {   66, AutoRotationPolicy::Never },
            {   67, AutoRotationPolicy::InTabletMode },
            {   68, AutoRotationPolicy::Always },
        }),
        // enum 'ColorPowerTradeoff'
        QtMocHelpers::EnumData<enum ColorPowerTradeoff>(69, 69, QMC::EnumIsScoped).add({
            {   70, ColorPowerTradeoff::PreferEfficiency },
            {   71, ColorPowerTradeoff::PreferAccuracy },
        }),
    };
    return QtMocHelpers::metaObjectData<Output, qt_meta_tag_ZN4KWin6OutputE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWin::Output::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KWin6OutputE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KWin6OutputE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4KWin6OutputE_t>.metaTypes,
    nullptr
} };

void KWin::Output::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Output *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->geometryChanged(); break;
        case 1: _t->enabledChanged(); break;
        case 2: _t->scaleChanged(); break;
        case 3: _t->aboutToTurnOff((*reinterpret_cast<std::add_pointer_t<std::chrono::milliseconds>>(_a[1]))); break;
        case 4: _t->wakeUp(); break;
        case 5: _t->aboutToChange((*reinterpret_cast<std::add_pointer_t<OutputChangeSet*>>(_a[1]))); break;
        case 6: _t->changed(); break;
        case 7: _t->currentModeChanged(); break;
        case 8: _t->modesChanged(); break;
        case 9: _t->outputChange((*reinterpret_cast<std::add_pointer_t<QRegion>>(_a[1]))); break;
        case 10: _t->transformChanged(); break;
        case 11: _t->dpmsModeChanged(); break;
        case 12: _t->capabilitiesChanged(); break;
        case 13: _t->overscanChanged(); break;
        case 14: _t->vrrPolicyChanged(); break;
        case 15: _t->rgbRangeChanged(); break;
        case 16: _t->wideColorGamutChanged(); break;
        case 17: _t->referenceLuminanceChanged(); break;
        case 18: _t->highDynamicRangeChanged(); break;
        case 19: _t->autoRotationPolicyChanged(); break;
        case 20: _t->iccProfileChanged(); break;
        case 21: _t->iccProfilePathChanged(); break;
        case 22: _t->brightnessMetadataChanged(); break;
        case 23: _t->sdrGamutWidenessChanged(); break;
        case 24: _t->colorDescriptionChanged(); break;
        case 25: _t->colorProfileSourceChanged(); break;
        case 26: _t->brightnessChanged(); break;
        case 27: _t->colorPowerTradeoffChanged(); break;
        case 28: _t->dimmingChanged(); break;
        case 29: { QPointF _r = _t->mapToGlobal((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QPointF*>(_a[0]) = std::move(_r); }  break;
        case 30: { QPointF _r = _t->mapFromGlobal((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QPointF*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::geometryChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::enabledChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::scaleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)(std::chrono::milliseconds )>(_a, &Output::aboutToTurnOff, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::wakeUp, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)(OutputChangeSet * )>(_a, &Output::aboutToChange, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::changed, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::currentModeChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::modesChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)(const QRegion & )>(_a, &Output::outputChange, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::transformChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::dpmsModeChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::capabilitiesChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::overscanChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::vrrPolicyChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::rgbRangeChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::wideColorGamutChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::referenceLuminanceChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::highDynamicRangeChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::autoRotationPolicyChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::iccProfileChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::iccProfilePathChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::brightnessMetadataChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::sdrGamutWidenessChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::colorDescriptionChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::colorProfileSourceChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::brightnessChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::colorPowerTradeoffChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::dimmingChanged, 28))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QRect*>(_v) = _t->geometry(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->scale(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->manufacturer(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->model(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->serialNumber(); break;
        default: break;
        }
    }
}

const QMetaObject *KWin::Output::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWin::Output::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KWin6OutputE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KWin::Output::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 31)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 31)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 31;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void KWin::Output::geometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KWin::Output::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KWin::Output::scaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KWin::Output::aboutToTurnOff(std::chrono::milliseconds _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KWin::Output::wakeUp()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KWin::Output::aboutToChange(OutputChangeSet * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KWin::Output::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KWin::Output::currentModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KWin::Output::modesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KWin::Output::outputChange(const QRegion & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void KWin::Output::transformChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void KWin::Output::dpmsModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void KWin::Output::capabilitiesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void KWin::Output::overscanChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void KWin::Output::vrrPolicyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void KWin::Output::rgbRangeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void KWin::Output::wideColorGamutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void KWin::Output::referenceLuminanceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void KWin::Output::highDynamicRangeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void KWin::Output::autoRotationPolicyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void KWin::Output::iccProfileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void KWin::Output::iccProfilePathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void KWin::Output::brightnessMetadataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void KWin::Output::sdrGamutWidenessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void KWin::Output::colorDescriptionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void KWin::Output::colorProfileSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void KWin::Output::brightnessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void KWin::Output::colorPowerTradeoffChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void KWin::Output::dimmingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}
QT_WARNING_POP
