// This file is generated by kconfig_compiler_kf6 from blur.kcfg.
// All changes you do to this file will be lost.
#ifndef KWIN_BLURCONFIG_H
#define KWIN_BLURCONFIG_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

namespace KWin {

class BlurConfig : public KConfigSkeleton
{
  public:

    static BlurConfig *self();
    static void instance(const QString& cfgfilename);
    static void instance(KSharedConfig::Ptr config);
    ~BlurConfig() override;

    /**
      Set BlurStrength
    */
    static
    void setBlurStrength( int v )
    {
      if (!self()->isBlurStrengthImmutable())
        self()->mBlurStrength = v;
    }

    /**
      Get BlurStrength
    */
    static
    int blurStrength()
    {
      return self()->mBlurStrength;
    }

    /**
      Is BlurStrength Immutable
    */
    static
    bool isBlurStrengthImmutable()
    {
      return self()->isImmutable( QStringLiteral( "BlurStrength" ) );
    }

    /**
      Set NoiseStrength
    */
    static
    void setNoiseStrength( int v )
    {
      if (!self()->isNoiseStrengthImmutable())
        self()->mNoiseStrength = v;
    }

    /**
      Get NoiseStrength
    */
    static
    int noiseStrength()
    {
      return self()->mNoiseStrength;
    }

    /**
      Is NoiseStrength Immutable
    */
    static
    bool isNoiseStrengthImmutable()
    {
      return self()->isImmutable( QStringLiteral( "NoiseStrength" ) );
    }

  protected:
    BlurConfig(KSharedConfig::Ptr config);
    friend class BlurConfigHelper;


    // Effect-blur
    int mBlurStrength;
    int mNoiseStrength;
};

}

#endif

