// This file is generated by kconfig_compiler_kf6 from kwincompositing_setting.kcfg.
// All changes you do to this file will be lost.

#include "kwincompositing_setting.h"

KWinCompositingSetting::KWinCompositingSetting( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "kwinrc" ) )
{
  setParent(parent);
  setCurrentGroup( QStringLiteral( "KDE" ) );

  KConfigSkeleton::ItemDouble  *itemAnimationDurationFactor;
  itemAnimationDurationFactor = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "AnimationDurationFactor" ), mAnimationDurationFactor, 1.0 );
  addItem( itemAnimationDurationFactor, QStringLiteral( "AnimationDurationFactor" ) );

  setCurrentGroup( QStringLiteral( "Compositing" ) );

  QList<KConfigSkeleton::ItemEnum::Choice> valuesHiddenPreviews;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Off");
    valuesHiddenPreviews.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Shown");
    valuesHiddenPreviews.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Always");
    valuesHiddenPreviews.append( choice );
  }
  KConfigSkeleton::ItemEnum  *itemHiddenPreviews;
  itemHiddenPreviews = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "HiddenPreviews" ), mHiddenPreviews, valuesHiddenPreviews, EnumHiddenPreviews::Shown );
  itemHiddenPreviews->setValueForChoice(QStringLiteral( "Off" ), QStringLiteral( "4" ));
  itemHiddenPreviews->setValueForChoice(QStringLiteral( "Shown" ), QStringLiteral( "5" ));
  itemHiddenPreviews->setValueForChoice(QStringLiteral( "Always" ), QStringLiteral( "6" ));
  addItem( itemHiddenPreviews, QStringLiteral( "HiddenPreviews" ) );
  KConfigSkeleton::ItemBool  *itemEnabled;
  itemEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Enabled" ), mEnabled, true );
  addItem( itemEnabled, QStringLiteral( "Enabled" ) );
  KConfigSkeleton::ItemInt  *itemLastFailureTimestamp;
  itemLastFailureTimestamp = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "LastFailureTimestamp" ), mLastFailureTimestamp, 0 );
  addItem( itemLastFailureTimestamp, QStringLiteral( "LastFailureTimestamp" ) );
  KConfigSkeleton::ItemBool  *itemWindowsBlockCompositing;
  itemWindowsBlockCompositing = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "WindowsBlockCompositing" ), mWindowsBlockCompositing, true );
  addItem( itemWindowsBlockCompositing, QStringLiteral( "WindowsBlockCompositing" ) );
}

double KWinCompositingSetting::defaultAnimationDurationFactorValue_helper() const
{

  return 1.0;
}

int KWinCompositingSetting::defaultHiddenPreviewsValue_helper() const
{

  return EnumHiddenPreviews::Shown;
}

bool KWinCompositingSetting::defaultEnabledValue_helper() const
{

  return true;
}

int KWinCompositingSetting::defaultLastFailureTimestampValue_helper() const
{

  return 0;
}

bool KWinCompositingSetting::defaultWindowsBlockCompositingValue_helper() const
{

  return true;
}

KWinCompositingSetting::~KWinCompositingSetting()
{
}

