/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.KWin.ScreenShot2.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "screenshot2adaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class ScreenShot2Adaptor
 */

ScreenShot2Adaptor::ScreenShot2Adaptor(KWin::ScreenShotDBusInterface2 *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

ScreenShot2Adaptor::~ScreenShot2Adaptor()
{
    // destructor
}

uint ScreenShot2Adaptor::version() const
{
    // get the value of property Version
    return qvariant_cast< uint >(parent()->property("Version"));
}

QVariantMap ScreenShot2Adaptor::CaptureActiveScreen(const QVariantMap &options, const QDBusUnixFileDescriptor &pipe)
{
    // handle method call org.kde.KWin.ScreenShot2.CaptureActiveScreen
    return parent()->CaptureActiveScreen(options, pipe);
}

QVariantMap ScreenShot2Adaptor::CaptureActiveWindow(const QVariantMap &options, const QDBusUnixFileDescriptor &pipe)
{
    // handle method call org.kde.KWin.ScreenShot2.CaptureActiveWindow
    return parent()->CaptureActiveWindow(options, pipe);
}

QVariantMap ScreenShot2Adaptor::CaptureArea(int x, int y, uint width, uint height, const QVariantMap &options, const QDBusUnixFileDescriptor &pipe)
{
    // handle method call org.kde.KWin.ScreenShot2.CaptureArea
    return parent()->CaptureArea(x, y, width, height, options, pipe);
}

QVariantMap ScreenShot2Adaptor::CaptureInteractive(uint kind, const QVariantMap &options, const QDBusUnixFileDescriptor &pipe)
{
    // handle method call org.kde.KWin.ScreenShot2.CaptureInteractive
    return parent()->CaptureInteractive(kind, options, pipe);
}

QVariantMap ScreenShot2Adaptor::CaptureScreen(const QString &name, const QVariantMap &options, const QDBusUnixFileDescriptor &pipe)
{
    // handle method call org.kde.KWin.ScreenShot2.CaptureScreen
    return parent()->CaptureScreen(name, options, pipe);
}

QVariantMap ScreenShot2Adaptor::CaptureWindow(const QString &handle, const QVariantMap &options, const QDBusUnixFileDescriptor &pipe)
{
    // handle method call org.kde.KWin.ScreenShot2.CaptureWindow
    return parent()->CaptureWindow(handle, options, pipe);
}

QVariantMap ScreenShot2Adaptor::CaptureWorkspace(const QVariantMap &options, const QDBusUnixFileDescriptor &pipe)
{
    // handle method call org.kde.KWin.ScreenShot2.CaptureWorkspace
    return parent()->CaptureWorkspace(options, pipe);
}


#include "moc_screenshot2adaptor.cpp"
