// This file is generated by kconfig_compiler_kf6 from sheet.kcfg.
// All changes you do to this file will be lost.
#ifndef KWIN_SHEETCONFIG_H
#define KWIN_SHEETCONFIG_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

namespace KWin {

class SheetConfig : public KConfigSkeleton
{
  public:

    static SheetConfig *self();
    static void instance(const QString& cfgfilename);
    static void instance(KSharedConfig::Ptr config);
    ~SheetConfig() override;

    /**
      Set AnimationTime
    */
    static
    void setAnimationTime( int v )
    {
      if (!self()->isAnimationTimeImmutable())
        self()->mAnimationTime = v;
    }

    /**
      Get AnimationTime
    */
    static
    int animationTime()
    {
      return self()->mAnimationTime;
    }

    /**
      Is AnimationTime Immutable
    */
    static
    bool isAnimationTimeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "AnimationTime" ) );
    }

  protected:
    SheetConfig(KSharedConfig::Ptr config);
    friend class SheetConfigHelper;


    // Effect-sheet
    int mAnimationTime;
};

}

#endif

