/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kwin.Compositing.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef COMPOSITINGADAPTOR_H
#define COMPOSITINGADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "dbusinterface.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kwin.Compositing
 */
class CompositingAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kwin.Compositing")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kwin.Compositing\">\n"
"    <property access=\"read\" type=\"b\" name=\"active\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"compositingPossible\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"compositingNotPossibleReason\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"openGLIsBroken\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"compositingType\"/>\n"
"    <property access=\"read\" type=\"as\" name=\"supportedOpenGLPlatformInterfaces\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"platformRequiresCompositing\"/>\n"
"    <signal name=\"compositingToggled\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"active\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    CompositingAdaptor(KWin::CompositorDBusInterface *parent);
    ~CompositingAdaptor() override;

    inline KWin::CompositorDBusInterface *parent() const
    { return static_cast<KWin::CompositorDBusInterface *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(bool active READ active)
    bool active() const;

    Q_PROPERTY(QString compositingNotPossibleReason READ compositingNotPossibleReason)
    QString compositingNotPossibleReason() const;

    Q_PROPERTY(bool compositingPossible READ compositingPossible)
    bool compositingPossible() const;

    Q_PROPERTY(QString compositingType READ compositingType)
    QString compositingType() const;

    Q_PROPERTY(bool openGLIsBroken READ openGLIsBroken)
    bool openGLIsBroken() const;

    Q_PROPERTY(bool platformRequiresCompositing READ platformRequiresCompositing)
    bool platformRequiresCompositing() const;

    Q_PROPERTY(QStringList supportedOpenGLPlatformInterfaces READ supportedOpenGLPlatformInterfaces)
    QStringList supportedOpenGLPlatformInterfaces() const;

public Q_SLOTS: // METHODS
Q_SIGNALS: // SIGNALS
    void compositingToggled(bool active);
};

#endif
