/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.KWin.VirtualDesktopManager.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "virtualdesktopmanageradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class VirtualDesktopManagerAdaptor
 */

VirtualDesktopManagerAdaptor::VirtualDesktopManagerAdaptor(KWin::VirtualDesktopManagerDBusInterface *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

VirtualDesktopManagerAdaptor::~VirtualDesktopManagerAdaptor()
{
    // destructor
}

uint VirtualDesktopManagerAdaptor::count() const
{
    // get the value of property count
    return qvariant_cast< uint >(parent()->property("count"));
}

QString VirtualDesktopManagerAdaptor::current() const
{
    // get the value of property current
    return qvariant_cast< QString >(parent()->property("current"));
}

void VirtualDesktopManagerAdaptor::setCurrent(const QString &value)
{
    // set the value of property current
    parent()->setProperty("current", QVariant::fromValue(value));
}

KWin::DBusDesktopDataVector VirtualDesktopManagerAdaptor::desktops() const
{
    // get the value of property desktops
    return qvariant_cast< KWin::DBusDesktopDataVector >(parent()->property("desktops"));
}

bool VirtualDesktopManagerAdaptor::navigationWrappingAround() const
{
    // get the value of property navigationWrappingAround
    return qvariant_cast< bool >(parent()->property("navigationWrappingAround"));
}

void VirtualDesktopManagerAdaptor::setNavigationWrappingAround(bool value)
{
    // set the value of property navigationWrappingAround
    parent()->setProperty("navigationWrappingAround", QVariant::fromValue(value));
}

uint VirtualDesktopManagerAdaptor::rows() const
{
    // get the value of property rows
    return qvariant_cast< uint >(parent()->property("rows"));
}

void VirtualDesktopManagerAdaptor::setRows(uint value)
{
    // set the value of property rows
    parent()->setProperty("rows", QVariant::fromValue(value));
}

void VirtualDesktopManagerAdaptor::createDesktop(uint position, const QString &name)
{
    // handle method call org.kde.KWin.VirtualDesktopManager.createDesktop
    parent()->createDesktop(position, name);
}

void VirtualDesktopManagerAdaptor::removeDesktop(const QString &id)
{
    // handle method call org.kde.KWin.VirtualDesktopManager.removeDesktop
    parent()->removeDesktop(id);
}

void VirtualDesktopManagerAdaptor::setDesktopName(const QString &id, const QString &name)
{
    // handle method call org.kde.KWin.VirtualDesktopManager.setDesktopName
    parent()->setDesktopName(id, name);
}


#include "moc_virtualdesktopmanageradaptor.cpp"
