/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kwin.Compositing.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef KWIN_COMPOSITING_INTERFACE_H
#define KWIN_COMPOSITING_INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.kwin.Compositing
 */
class OrgKdeKwinCompositingInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.kwin.Compositing"; }

public:
    OrgKdeKwinCompositingInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeKwinCompositingInterface();

    Q_PROPERTY(bool active READ active)
    inline bool active() const
    { return qvariant_cast< bool >(property("active")); }

    Q_PROPERTY(QString compositingNotPossibleReason READ compositingNotPossibleReason)
    inline QString compositingNotPossibleReason() const
    { return qvariant_cast< QString >(property("compositingNotPossibleReason")); }

    Q_PROPERTY(bool compositingPossible READ compositingPossible)
    inline bool compositingPossible() const
    { return qvariant_cast< bool >(property("compositingPossible")); }

    Q_PROPERTY(QString compositingType READ compositingType)
    inline QString compositingType() const
    { return qvariant_cast< QString >(property("compositingType")); }

    Q_PROPERTY(bool openGLIsBroken READ openGLIsBroken)
    inline bool openGLIsBroken() const
    { return qvariant_cast< bool >(property("openGLIsBroken")); }

    Q_PROPERTY(bool platformRequiresCompositing READ platformRequiresCompositing)
    inline bool platformRequiresCompositing() const
    { return qvariant_cast< bool >(property("platformRequiresCompositing")); }

    Q_PROPERTY(QStringList supportedOpenGLPlatformInterfaces READ supportedOpenGLPlatformInterfaces)
    inline QStringList supportedOpenGLPlatformInterfaces() const
    { return qvariant_cast< QStringList >(property("supportedOpenGLPlatformInterfaces")); }

public Q_SLOTS: // METHODS
Q_SIGNALS: // SIGNALS
    void compositingToggled(bool active);
};

namespace org {
  namespace kde {
    namespace kwin {
      using Compositing = ::OrgKdeKwinCompositingInterface;
    }
  }
}

#endif
