// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#include "kwinscreenedgedata.h"

#include "kwinscreenedgesettings.h"


namespace KWin {

KWinScreenEdgeData::KWinScreenEdgeData(QObject *parent)
: KCModuleData(parent)
, m_settings(new KWinScreenEdgeSettings(this))

{
autoRegisterSkeletons();
}

KWinScreenEdgeSettings *KWinScreenEdgeData::settings() const
{
    return m_settings;
}



}

#include "moc_kwinscreenedgedata.cpp"
