// This file was generated by qtwaylandscanner
// source file is cursor-shape-v1.xml

#ifndef QT_WAYLAND_SERVER_CURSOR_SHAPE_V1
#define QT_WAYLAND_SERVER_CURSOR_SHAPE_V1

#include "wayland-server-core.h"
#include "wayland-cursor-shape-v1-server-protocol.h"
#include <QByteArray>
#include <QMultiMap>
#include <QString>

#include <unistd.h>

#ifndef WAYLAND_VERSION_CHECK
#define WAYLAND_VERSION_CHECK(major, minor, micro) \
    ((WAYLAND_VERSION_MAJOR > (major)) || \
    (WAYLAND_VERSION_MAJOR == (major) && WAYLAND_VERSION_MINOR > (minor)) || \
    (WAYLAND_VERSION_MAJOR == (major) && WAYLAND_VERSION_MINOR == (minor) && WAYLAND_VERSION_MICRO >= (micro)))
#endif

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWaylandServer {
    class  wp_cursor_shape_manager_v1
    {
    public:
        wp_cursor_shape_manager_v1(struct ::wl_client *client, int id, int version);
        wp_cursor_shape_manager_v1(struct ::wl_display *display, int version);
        wp_cursor_shape_manager_v1(struct ::wl_resource *resource);
        wp_cursor_shape_manager_v1();

        virtual ~wp_cursor_shape_manager_v1();

        class Resource
        {
        public:
            Resource() : wp_cursor_shape_manager_v1_object(nullptr), handle(nullptr) {}
            virtual ~Resource() {}

            wp_cursor_shape_manager_v1 *wp_cursor_shape_manager_v1_object;
            wp_cursor_shape_manager_v1 *object() { return wp_cursor_shape_manager_v1_object; } 
            struct ::wl_resource *handle;

            struct ::wl_client *client() const { return wl_resource_get_client(handle); }
            int version() const { return wl_resource_get_version(handle); }

            static Resource *fromResource(struct ::wl_resource *resource);
        };

        void init(struct ::wl_client *client, int id, int version);
        void init(struct ::wl_display *display, int version);
        void init(struct ::wl_resource *resource);

        Resource *add(struct ::wl_client *client, int version);
        Resource *add(struct ::wl_client *client, int id, int version);
        Resource *add(struct wl_list *resource_list, struct ::wl_client *client, int id, int version);

        Resource *resource() { return m_resource; }
        const Resource *resource() const { return m_resource; }

        QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
        const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }

        bool isGlobalRemoved() const { return m_globalRemovedEvent; }
        void globalRemove();

        bool isGlobal() const { return m_global != nullptr; }
        bool isResource() const { return m_resource != nullptr; }

        static const struct ::wl_interface *interface();
        static QByteArray interfaceName() { return interface()->name; }
        static int interfaceVersion() { return interface()->version; }


    protected:
        virtual Resource *wp_cursor_shape_manager_v1_allocate();

        virtual void wp_cursor_shape_manager_v1_destroy_global();

        virtual void wp_cursor_shape_manager_v1_bind_resource(Resource *resource);
        virtual void wp_cursor_shape_manager_v1_destroy_resource(Resource *resource);

        virtual void wp_cursor_shape_manager_v1_destroy(Resource *resource);
        virtual void wp_cursor_shape_manager_v1_get_pointer(Resource *resource, uint32_t cursor_shape_device, struct ::wl_resource *pointer);
        virtual void wp_cursor_shape_manager_v1_get_tablet_tool_v2(Resource *resource, uint32_t cursor_shape_device, struct ::wl_resource *tablet_tool);

    private:
        static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
        static void destroy_func(struct ::wl_resource *client_resource);
        static void display_destroy_func(struct ::wl_listener *listener, void *data);
        static int deferred_destroy_global_func(void *data);

        Resource *bind(struct ::wl_client *client, uint32_t id, int version);
        Resource *bind(struct ::wl_resource *handle);

        static const struct ::wp_cursor_shape_manager_v1_interface m_wp_cursor_shape_manager_v1_interface;

        static void handle_destroy(
            ::wl_client *client,
            struct wl_resource *resource);
        static void handle_get_pointer(
            ::wl_client *client,
            struct wl_resource *resource,
            uint32_t cursor_shape_device,
            struct ::wl_resource *pointer);
        static void handle_get_tablet_tool_v2(
            ::wl_client *client,
            struct wl_resource *resource,
            uint32_t cursor_shape_device,
            struct ::wl_resource *tablet_tool);

        QMultiMap<struct ::wl_client*, Resource*> m_resource_map;
        Resource *m_resource;
        struct ::wl_global *m_global;
        struct ::wl_display *m_display;
        struct wl_event_source *m_globalRemovedEvent;
        struct DisplayDestroyedListener : ::wl_listener {
            wp_cursor_shape_manager_v1 *parent;
        };
        DisplayDestroyedListener m_displayDestroyedListener;
    };

    class  wp_cursor_shape_device_v1
    {
    public:
        wp_cursor_shape_device_v1(struct ::wl_client *client, int id, int version);
        wp_cursor_shape_device_v1(struct ::wl_display *display, int version);
        wp_cursor_shape_device_v1(struct ::wl_resource *resource);
        wp_cursor_shape_device_v1();

        virtual ~wp_cursor_shape_device_v1();

        class Resource
        {
        public:
            Resource() : wp_cursor_shape_device_v1_object(nullptr), handle(nullptr) {}
            virtual ~Resource() {}

            wp_cursor_shape_device_v1 *wp_cursor_shape_device_v1_object;
            wp_cursor_shape_device_v1 *object() { return wp_cursor_shape_device_v1_object; } 
            struct ::wl_resource *handle;

            struct ::wl_client *client() const { return wl_resource_get_client(handle); }
            int version() const { return wl_resource_get_version(handle); }

            static Resource *fromResource(struct ::wl_resource *resource);
        };

        void init(struct ::wl_client *client, int id, int version);
        void init(struct ::wl_display *display, int version);
        void init(struct ::wl_resource *resource);

        Resource *add(struct ::wl_client *client, int version);
        Resource *add(struct ::wl_client *client, int id, int version);
        Resource *add(struct wl_list *resource_list, struct ::wl_client *client, int id, int version);

        Resource *resource() { return m_resource; }
        const Resource *resource() const { return m_resource; }

        QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
        const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }

        bool isGlobalRemoved() const { return m_globalRemovedEvent; }
        void globalRemove();

        bool isGlobal() const { return m_global != nullptr; }
        bool isResource() const { return m_resource != nullptr; }

        static const struct ::wl_interface *interface();
        static QByteArray interfaceName() { return interface()->name; }
        static int interfaceVersion() { return interface()->version; }


        enum shape {
            shape_default = 1, // default cursor
            shape_context_menu = 2, // a context menu is available for the object under the cursor
            shape_help = 3, // help is available for the object under the cursor
            shape_pointer = 4, // pointer that indicates a link or another interactive element
            shape_progress = 5, // progress indicator
            shape_wait = 6, // program is busy, user should wait
            shape_cell = 7, // a cell or set of cells may be selected
            shape_crosshair = 8, // simple crosshair
            shape_text = 9, // text may be selected
            shape_vertical_text = 10, // vertical text may be selected
            shape_alias = 11, // drag-and-drop: alias of/shortcut to something is to be created
            shape_copy = 12, // drag-and-drop: something is to be copied
            shape_move = 13, // drag-and-drop: something is to be moved
            shape_no_drop = 14, // drag-and-drop: the dragged item cannot be dropped at the current cursor location
            shape_not_allowed = 15, // drag-and-drop: the requested action will not be carried out
            shape_grab = 16, // drag-and-drop: something can be grabbed
            shape_grabbing = 17, // drag-and-drop: something is being grabbed
            shape_e_resize = 18, // resizing: the east border is to be moved
            shape_n_resize = 19, // resizing: the north border is to be moved
            shape_ne_resize = 20, // resizing: the north-east corner is to be moved
            shape_nw_resize = 21, // resizing: the north-west corner is to be moved
            shape_s_resize = 22, // resizing: the south border is to be moved
            shape_se_resize = 23, // resizing: the south-east corner is to be moved
            shape_sw_resize = 24, // resizing: the south-west corner is to be moved
            shape_w_resize = 25, // resizing: the west border is to be moved
            shape_ew_resize = 26, // resizing: the east and west borders are to be moved
            shape_ns_resize = 27, // resizing: the north and south borders are to be moved
            shape_nesw_resize = 28, // resizing: the north-east and south-west corners are to be moved
            shape_nwse_resize = 29, // resizing: the north-west and south-east corners are to be moved
            shape_col_resize = 30, // resizing: that the item/column can be resized horizontally
            shape_row_resize = 31, // resizing: that the item/row can be resized vertically
            shape_all_scroll = 32, // something can be scrolled in any direction
            shape_zoom_in = 33, // something can be zoomed in
            shape_zoom_out = 34, // something can be zoomed out
            shape_dnd_ask = 35, // drag-and-drop: the user will select which action will be carried out (non-css value)
            shape_all_resize = 36, // resizing: something can be moved or resized in any direction (non-css value)
        };

        enum error {
            error_invalid_shape = 1, // the specified shape value is invalid
        };

    protected:
        virtual Resource *wp_cursor_shape_device_v1_allocate();

        virtual void wp_cursor_shape_device_v1_destroy_global();

        virtual void wp_cursor_shape_device_v1_bind_resource(Resource *resource);
        virtual void wp_cursor_shape_device_v1_destroy_resource(Resource *resource);

        virtual void wp_cursor_shape_device_v1_destroy(Resource *resource);
        virtual void wp_cursor_shape_device_v1_set_shape(Resource *resource, uint32_t serial, uint32_t shape);

    private:
        static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
        static void destroy_func(struct ::wl_resource *client_resource);
        static void display_destroy_func(struct ::wl_listener *listener, void *data);
        static int deferred_destroy_global_func(void *data);

        Resource *bind(struct ::wl_client *client, uint32_t id, int version);
        Resource *bind(struct ::wl_resource *handle);

        static const struct ::wp_cursor_shape_device_v1_interface m_wp_cursor_shape_device_v1_interface;

        static void handle_destroy(
            ::wl_client *client,
            struct wl_resource *resource);
        static void handle_set_shape(
            ::wl_client *client,
            struct wl_resource *resource,
            uint32_t serial,
            uint32_t shape);

        QMultiMap<struct ::wl_client*, Resource*> m_resource_map;
        Resource *m_resource;
        struct ::wl_global *m_global;
        struct ::wl_display *m_display;
        struct wl_event_source *m_globalRemovedEvent;
        struct DisplayDestroyedListener : ::wl_listener {
            wp_cursor_shape_device_v1 *parent;
        };
        DisplayDestroyedListener m_displayDestroyedListener;
    };
}

QT_WARNING_POP
QT_END_NAMESPACE

#endif
