/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.KWin.Session.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef SESSIONADAPTOR_H
#define SESSIONADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "sm.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.KWin.Session
 */
class SessionAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.KWin.Session")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.KWin.Session\">\n"
"    <method name=\"setState\">\n"
"      <arg direction=\"in\" type=\"u\" name=\"state\"/>\n"
"    </method>\n"
"    <method name=\"loadSession\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
"    </method>\n"
"    <method name=\"aboutToSaveSession\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
"    </method>\n"
"    <method name=\"finishSaveSession\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
"    </method>\n"
"    <method name=\"quit\"/>\n"
"    <method name=\"closeWaylandWindows\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    SessionAdaptor(KWin::SessionManager *parent);
    ~SessionAdaptor() override;

    inline KWin::SessionManager *parent() const
    { return static_cast<KWin::SessionManager *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void aboutToSaveSession(const QString &name);
    bool closeWaylandWindows();
    void finishSaveSession(const QString &name);
    void loadSession(const QString &name);
    void quit();
    void setState(uint state);
Q_SIGNALS: // SIGNALS
};

#endif
