// This file is generated by kconfig_compiler_kf6 from kwinoptions_settings.kcfg.
// All changes you do to this file will be lost.
#ifndef KWINOPTIONSSETTINGS_H
#define KWINOPTIONSSETTINGS_H

#include <options.h>

#include <qglobal.h>
#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class KWinOptionsSettings : public KConfigSkeleton
{
  public:
    enum PlacementChoices { Smart, Maximizing, Random, Centered, ZeroCornered, UnderMouse };
    enum ActivationDesktopPolicyChoices { SwitchToOtherDesktop, BringToCurrentDesktop };
    class EnumTitlebarDoubleClickCommand
    {
      public:
      enum type { Maximize, MaximizeVerticalOnly, MaximizeHorizontalOnly, Minimize, Shade, Lower, Close, OnAllDesktops, Nothing, COUNT };
    };
    class EnumMaximizeButtonLeftClickCommand
    {
      public:
      enum type { Maximize, MaximizeVerticalOnly, MaximizeHorizontalOnly, COUNT };
    };
    class EnumMaximizeButtonMiddleClickCommand
    {
      public:
      enum type { Maximize, MaximizeVerticalOnly, MaximizeHorizontalOnly, COUNT };
    };
    class EnumMaximizeButtonRightClickCommand
    {
      public:
      enum type { Maximize, MaximizeVerticalOnly, MaximizeHorizontalOnly, COUNT };
    };
    class EnumFocusPolicy
    {
      public:
      enum type { ClickToFocus, FocusFollowsMouse, FocusUnderMouse, FocusStrictlyUnderMouse, COUNT };
    };
    class EnumCommandActiveTitlebar1
    {
      public:
      enum type { Raise, Lower, ToggleRaiseAndLower, Minimize, Shade, Close, OperationsMenu, Nothing, COUNT };
    };
    class EnumCommandActiveTitlebar2
    {
      public:
      enum type { Raise, Lower, ToggleRaiseAndLower, Minimize, Shade, Close, OperationsMenu, Nothing, COUNT };
    };
    class EnumCommandActiveTitlebar3
    {
      public:
      enum type { Raise, Lower, ToggleRaiseAndLower, Minimize, Shade, Close, OperationsMenu, Nothing, COUNT };
    };
    class EnumCommandTitlebarWheel
    {
      public:
      enum type { RaiseLower, ShadeUnshade, MaxmizeRestore, AboveBelow, PreviousNextDesktop, ChangeOpacity, Nothing, COUNT };
    };
    class EnumCommandInactiveTitlebar1
    {
      public:
      enum type { ActivateRaiseOnReleaseAndPassClick, ActivateAndRaise, ActivateAndLower, Activate, Raise, Lower, ToggleRaiseAndLower, Minimize, Shade, Close, OperationsMenu, Nothing, COUNT };
    };
    class EnumCommandInactiveTitlebar2
    {
      public:
      enum type { ActivateAndRaise, ActivateAndLower, Activate, Raise, Lower, ToggleRaiseAndLower, Minimize, Shade, Close, OperationsMenu, Nothing, COUNT };
    };
    class EnumCommandInactiveTitlebar3
    {
      public:
      enum type { ActivateAndRaise, ActivateAndLower, Activate, Raise, Lower, ToggleRaiseAndLower, Minimize, Shade, Close, OperationsMenu, Nothing, COUNT };
    };
    class EnumCommandWindow1
    {
      public:
      enum type { ActivateRaisePassClick, ActivatePassClick, Activate, ActivateRaise, COUNT };
    };
    class EnumCommandWindow2
    {
      public:
      enum type { ActivateRaisePassClick, ActivatePassClick, Activate, ActivateRaise, COUNT };
    };
    class EnumCommandWindow3
    {
      public:
      enum type { ActivateRaisePassClick, ActivatePassClick, Activate, ActivateRaise, COUNT };
    };
    class EnumCommandWindowWheel
    {
      public:
      enum type { Scroll, ActivateScroll, ActivateRaiseAndScroll, COUNT };
    };
    class EnumCommandAllKey
    {
      public:
      enum type { Meta, Alt, COUNT };
    };
    class EnumCommandAll1
    {
      public:
      enum type { Move, ActivateRaiseAndMove, ToggleRaiseAndLower, Resize, Raise, Lower, Minimize, DecreaseOpacity, IncreaseOpactiy, Nothing, COUNT };
    };
    class EnumCommandAll2
    {
      public:
      enum type { Move, ActivateRaiseAndMove, ToggleRaiseAndLower, Resize, Raise, Lower, Minimize, DecreaseOpacity, IncreaseOpactiy, Nothing, COUNT };
    };
    class EnumCommandAll3
    {
      public:
      enum type { Move, ActivateRaiseAndMove, ToggleRaiseAndLower, Resize, Raise, Lower, Minimize, DecreaseOpacity, IncreaseOpactiy, Nothing, COUNT };
    };
    class EnumCommandAllWheel
    {
      public:
      enum type { RaiseLower, ShadeUnshade, MaxmizeRestore, AboveBelow, PreviousNextDesktop, ChangeOpacity, Nothing, COUNT };
    };

    KWinOptionsSettings( QObject *parent = nullptr );
    ~KWinOptionsSettings() override;

    /**
      Set BorderSnapZone
    */
    void setBorderSnapZone( int v )
    {
      if (v < 0)
      {
        qDebug() << "setBorderSnapZone: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBorderSnapZone: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (!isBorderSnapZoneImmutable())
        mBorderSnapZone = v;
    }

    /**
      Get BorderSnapZone
    */
    int borderSnapZone() const
    {
      return mBorderSnapZone;
    }

    /**
      Is BorderSnapZone Immutable
    */
    bool isBorderSnapZoneImmutable() const
    {
      return isImmutable( QStringLiteral( "BorderSnapZone" ) );
    }

    /**
      Get BorderSnapZone default value
    */
    int defaultBorderSnapZoneValue() const
    {
        return defaultBorderSnapZoneValue_helper();
    }

    /**
      Set WindowSnapZone
    */
    void setWindowSnapZone( int v )
    {
      if (v < 0)
      {
        qDebug() << "setWindowSnapZone: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setWindowSnapZone: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (!isWindowSnapZoneImmutable())
        mWindowSnapZone = v;
    }

    /**
      Get WindowSnapZone
    */
    int windowSnapZone() const
    {
      return mWindowSnapZone;
    }

    /**
      Is WindowSnapZone Immutable
    */
    bool isWindowSnapZoneImmutable() const
    {
      return isImmutable( QStringLiteral( "WindowSnapZone" ) );
    }

    /**
      Get WindowSnapZone default value
    */
    int defaultWindowSnapZoneValue() const
    {
        return defaultWindowSnapZoneValue_helper();
    }

    /**
      Set CenterSnapZone
    */
    void setCenterSnapZone( int v )
    {
      if (v < 0)
      {
        qDebug() << "setCenterSnapZone: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setCenterSnapZone: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (!isCenterSnapZoneImmutable())
        mCenterSnapZone = v;
    }

    /**
      Get CenterSnapZone
    */
    int centerSnapZone() const
    {
      return mCenterSnapZone;
    }

    /**
      Is CenterSnapZone Immutable
    */
    bool isCenterSnapZoneImmutable() const
    {
      return isImmutable( QStringLiteral( "CenterSnapZone" ) );
    }

    /**
      Get CenterSnapZone default value
    */
    int defaultCenterSnapZoneValue() const
    {
        return defaultCenterSnapZoneValue_helper();
    }

    /**
      Set SnapOnlyWhenOverlapping
    */
    void setSnapOnlyWhenOverlapping( bool v )
    {
      if (!isSnapOnlyWhenOverlappingImmutable())
        mSnapOnlyWhenOverlapping = v;
    }

    /**
      Get SnapOnlyWhenOverlapping
    */
    bool snapOnlyWhenOverlapping() const
    {
      return mSnapOnlyWhenOverlapping;
    }

    /**
      Is SnapOnlyWhenOverlapping Immutable
    */
    bool isSnapOnlyWhenOverlappingImmutable() const
    {
      return isImmutable( QStringLiteral( "SnapOnlyWhenOverlapping" ) );
    }

    /**
      Get SnapOnlyWhenOverlapping default value
    */
    bool defaultSnapOnlyWhenOverlappingValue() const
    {
        return defaultSnapOnlyWhenOverlappingValue_helper();
    }

    /**
      Set ShadeHover
    */
    void setShadeHover( bool v )
    {
      if (!isShadeHoverImmutable())
        mShadeHover = v;
    }

    /**
      Get ShadeHover
    */
    bool shadeHover() const
    {
      return mShadeHover;
    }

    /**
      Is ShadeHover Immutable
    */
    bool isShadeHoverImmutable() const
    {
      return isImmutable( QStringLiteral( "ShadeHover" ) );
    }

    /**
      Get ShadeHover default value
    */
    bool defaultShadeHoverValue() const
    {
        return defaultShadeHoverValue_helper();
    }

    /**
      Set ShadeHoverInterval
    */
    void setShadeHoverInterval( int v )
    {
      if (v < 0)
      {
        qDebug() << "setShadeHoverInterval: value " << v << " is less than the minimum value of 0";
        v = 0;
      }
      if (!isShadeHoverIntervalImmutable())
        mShadeHoverInterval = v;
    }

    /**
      Get ShadeHoverInterval
    */
    int shadeHoverInterval() const
    {
      return mShadeHoverInterval;
    }

    /**
      Is ShadeHoverInterval Immutable
    */
    bool isShadeHoverIntervalImmutable() const
    {
      return isImmutable( QStringLiteral( "ShadeHoverInterval" ) );
    }

    /**
      Get ShadeHoverInterval default value
    */
    int defaultShadeHoverIntervalValue() const
    {
        return defaultShadeHoverIntervalValue_helper();
    }

    /**
      Set Placement
    */
    void setPlacement( int v )
    {
      if (!isPlacementImmutable())
        mPlacement = v;
    }

    /**
      Get Placement
    */
    int placement() const
    {
      return mPlacement;
    }

    /**
      Is Placement Immutable
    */
    bool isPlacementImmutable() const
    {
      return isImmutable( QStringLiteral( "Placement" ) );
    }

    /**
      Get Placement default value
    */
    int defaultPlacementValue() const
    {
        return defaultPlacementValue_helper();
    }

    /**
      Set ActivationDesktopPolicy
    */
    void setActivationDesktopPolicy( int v )
    {
      if (!isActivationDesktopPolicyImmutable())
        mActivationDesktopPolicy = v;
    }

    /**
      Get ActivationDesktopPolicy
    */
    int activationDesktopPolicy() const
    {
      return mActivationDesktopPolicy;
    }

    /**
      Is ActivationDesktopPolicy Immutable
    */
    bool isActivationDesktopPolicyImmutable() const
    {
      return isImmutable( QStringLiteral( "ActivationDesktopPolicy" ) );
    }

    /**
      Get ActivationDesktopPolicy default value
    */
    int defaultActivationDesktopPolicyValue() const
    {
        return defaultActivationDesktopPolicyValue_helper();
    }

    /**
      Set TitlebarDoubleClickCommand
    */
    void setTitlebarDoubleClickCommand( int v )
    {
      if (!isTitlebarDoubleClickCommandImmutable())
        mTitlebarDoubleClickCommand = v;
    }

    /**
      Get TitlebarDoubleClickCommand
    */
    int titlebarDoubleClickCommand() const
    {
      return mTitlebarDoubleClickCommand;
    }

    /**
      Is TitlebarDoubleClickCommand Immutable
    */
    bool isTitlebarDoubleClickCommandImmutable() const
    {
      return isImmutable( QStringLiteral( "TitlebarDoubleClickCommand" ) );
    }

    /**
      Get TitlebarDoubleClickCommand default value
    */
    int defaultTitlebarDoubleClickCommandValue() const
    {
        return defaultTitlebarDoubleClickCommandValue_helper();
    }

    /**
      Set MaximizeButtonLeftClickCommand
    */
    void setMaximizeButtonLeftClickCommand( int v )
    {
      if (!isMaximizeButtonLeftClickCommandImmutable())
        mMaximizeButtonLeftClickCommand = v;
    }

    /**
      Get MaximizeButtonLeftClickCommand
    */
    int maximizeButtonLeftClickCommand() const
    {
      return mMaximizeButtonLeftClickCommand;
    }

    /**
      Is MaximizeButtonLeftClickCommand Immutable
    */
    bool isMaximizeButtonLeftClickCommandImmutable() const
    {
      return isImmutable( QStringLiteral( "MaximizeButtonLeftClickCommand" ) );
    }

    /**
      Get MaximizeButtonLeftClickCommand default value
    */
    int defaultMaximizeButtonLeftClickCommandValue() const
    {
        return defaultMaximizeButtonLeftClickCommandValue_helper();
    }

    /**
      Set MaximizeButtonMiddleClickCommand
    */
    void setMaximizeButtonMiddleClickCommand( int v )
    {
      if (!isMaximizeButtonMiddleClickCommandImmutable())
        mMaximizeButtonMiddleClickCommand = v;
    }

    /**
      Get MaximizeButtonMiddleClickCommand
    */
    int maximizeButtonMiddleClickCommand() const
    {
      return mMaximizeButtonMiddleClickCommand;
    }

    /**
      Is MaximizeButtonMiddleClickCommand Immutable
    */
    bool isMaximizeButtonMiddleClickCommandImmutable() const
    {
      return isImmutable( QStringLiteral( "MaximizeButtonMiddleClickCommand" ) );
    }

    /**
      Get MaximizeButtonMiddleClickCommand default value
    */
    int defaultMaximizeButtonMiddleClickCommandValue() const
    {
        return defaultMaximizeButtonMiddleClickCommandValue_helper();
    }

    /**
      Set MaximizeButtonRightClickCommand
    */
    void setMaximizeButtonRightClickCommand( int v )
    {
      if (!isMaximizeButtonRightClickCommandImmutable())
        mMaximizeButtonRightClickCommand = v;
    }

    /**
      Get MaximizeButtonRightClickCommand
    */
    int maximizeButtonRightClickCommand() const
    {
      return mMaximizeButtonRightClickCommand;
    }

    /**
      Is MaximizeButtonRightClickCommand Immutable
    */
    bool isMaximizeButtonRightClickCommandImmutable() const
    {
      return isImmutable( QStringLiteral( "MaximizeButtonRightClickCommand" ) );
    }

    /**
      Get MaximizeButtonRightClickCommand default value
    */
    int defaultMaximizeButtonRightClickCommandValue() const
    {
        return defaultMaximizeButtonRightClickCommandValue_helper();
    }

    /**
      Set FocusPolicy
    */
    void setFocusPolicy( int v )
    {
      if (!isFocusPolicyImmutable())
        mFocusPolicy = v;
    }

    /**
      Get FocusPolicy
    */
    int focusPolicy() const
    {
      return mFocusPolicy;
    }

    /**
      Is FocusPolicy Immutable
    */
    bool isFocusPolicyImmutable() const
    {
      return isImmutable( QStringLiteral( "FocusPolicy" ) );
    }

    /**
      Get FocusPolicy default value
    */
    int defaultFocusPolicyValue() const
    {
        return defaultFocusPolicyValue_helper();
    }

    /**
      Set NextFocusPrefersMouse
    */
    void setNextFocusPrefersMouse( bool v )
    {
      if (!isNextFocusPrefersMouseImmutable())
        mNextFocusPrefersMouse = v;
    }

    /**
      Get NextFocusPrefersMouse
    */
    bool nextFocusPrefersMouse() const
    {
      return mNextFocusPrefersMouse;
    }

    /**
      Is NextFocusPrefersMouse Immutable
    */
    bool isNextFocusPrefersMouseImmutable() const
    {
      return isImmutable( QStringLiteral( "NextFocusPrefersMouse" ) );
    }

    /**
      Get NextFocusPrefersMouse default value
    */
    bool defaultNextFocusPrefersMouseValue() const
    {
        return defaultNextFocusPrefersMouseValue_helper();
    }

    /**
      Set AutoRaiseInterval
    */
    void setAutoRaiseInterval( int v )
    {
      if (v < 0)
      {
        qDebug() << "setAutoRaiseInterval: value " << v << " is less than the minimum value of 0";
        v = 0;
      }
      if (!isAutoRaiseIntervalImmutable())
        mAutoRaiseInterval = v;
    }

    /**
      Get AutoRaiseInterval
    */
    int autoRaiseInterval() const
    {
      return mAutoRaiseInterval;
    }

    /**
      Is AutoRaiseInterval Immutable
    */
    bool isAutoRaiseIntervalImmutable() const
    {
      return isImmutable( QStringLiteral( "AutoRaiseInterval" ) );
    }

    /**
      Get AutoRaiseInterval default value
    */
    int defaultAutoRaiseIntervalValue() const
    {
        return defaultAutoRaiseIntervalValue_helper();
    }

    /**
      Set DelayFocusInterval
    */
    void setDelayFocusInterval( int v )
    {
      if (v < 0)
      {
        qDebug() << "setDelayFocusInterval: value " << v << " is less than the minimum value of 0";
        v = 0;
      }
      if (!isDelayFocusIntervalImmutable())
        mDelayFocusInterval = v;
    }

    /**
      Get DelayFocusInterval
    */
    int delayFocusInterval() const
    {
      return mDelayFocusInterval;
    }

    /**
      Is DelayFocusInterval Immutable
    */
    bool isDelayFocusIntervalImmutable() const
    {
      return isImmutable( QStringLiteral( "DelayFocusInterval" ) );
    }

    /**
      Get DelayFocusInterval default value
    */
    int defaultDelayFocusIntervalValue() const
    {
        return defaultDelayFocusIntervalValue_helper();
    }

    /**
      Set AutoRaise
    */
    void setAutoRaise( bool v )
    {
      if (!isAutoRaiseImmutable())
        mAutoRaise = v;
    }

    /**
      Get AutoRaise
    */
    bool autoRaise() const
    {
      return mAutoRaise;
    }

    /**
      Is AutoRaise Immutable
    */
    bool isAutoRaiseImmutable() const
    {
      return isImmutable( QStringLiteral( "AutoRaise" ) );
    }

    /**
      Get AutoRaise default value
    */
    bool defaultAutoRaiseValue() const
    {
        return defaultAutoRaiseValue_helper();
    }

    /**
      Set ClickRaise
    */
    void setClickRaise( bool v )
    {
      if (!isClickRaiseImmutable())
        mClickRaise = v;
    }

    /**
      Get ClickRaise
    */
    bool clickRaise() const
    {
      return mClickRaise;
    }

    /**
      Is ClickRaise Immutable
    */
    bool isClickRaiseImmutable() const
    {
      return isImmutable( QStringLiteral( "ClickRaise" ) );
    }

    /**
      Get ClickRaise default value
    */
    bool defaultClickRaiseValue() const
    {
        return defaultClickRaiseValue_helper();
    }

    /**
      Set SeparateScreenFocus
    */
    void setSeparateScreenFocus( bool v )
    {
      if (!isSeparateScreenFocusImmutable())
        mSeparateScreenFocus = v;
    }

    /**
      Get SeparateScreenFocus
    */
    bool separateScreenFocus() const
    {
      return mSeparateScreenFocus;
    }

    /**
      Is SeparateScreenFocus Immutable
    */
    bool isSeparateScreenFocusImmutable() const
    {
      return isImmutable( QStringLiteral( "SeparateScreenFocus" ) );
    }

    /**
      Get SeparateScreenFocus default value
    */
    bool defaultSeparateScreenFocusValue() const
    {
        return defaultSeparateScreenFocusValue_helper();
    }

    /**
      Set FocusStealingPreventionLevel
    */
    void setFocusStealingPreventionLevel( int v )
    {
      if (v < 0)
      {
        qDebug() << "setFocusStealingPreventionLevel: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 4)
      {
        qDebug() << "setFocusStealingPreventionLevel: value " << v << " is greater than the maximum value of 4";
        v = 4;
      }

      if (!isFocusStealingPreventionLevelImmutable())
        mFocusStealingPreventionLevel = v;
    }

    /**
      Get FocusStealingPreventionLevel
    */
    int focusStealingPreventionLevel() const
    {
      return mFocusStealingPreventionLevel;
    }

    /**
      Is FocusStealingPreventionLevel Immutable
    */
    bool isFocusStealingPreventionLevelImmutable() const
    {
      return isImmutable( QStringLiteral( "FocusStealingPreventionLevel" ) );
    }

    /**
      Get FocusStealingPreventionLevel default value
    */
    int defaultFocusStealingPreventionLevelValue() const
    {
        return defaultFocusStealingPreventionLevelValue_helper();
    }

    /**
      Set CommandActiveTitlebar1
    */
    void setCommandActiveTitlebar1( int v )
    {
      if (!isCommandActiveTitlebar1Immutable())
        mCommandActiveTitlebar1 = v;
    }

    /**
      Get CommandActiveTitlebar1
    */
    int commandActiveTitlebar1() const
    {
      return mCommandActiveTitlebar1;
    }

    /**
      Is CommandActiveTitlebar1 Immutable
    */
    bool isCommandActiveTitlebar1Immutable() const
    {
      return isImmutable( QStringLiteral( "CommandActiveTitlebar1" ) );
    }

    /**
      Get CommandActiveTitlebar1 default value
    */
    int defaultCommandActiveTitlebar1Value() const
    {
        return defaultCommandActiveTitlebar1Value_helper();
    }

    /**
      Set CommandActiveTitlebar2
    */
    void setCommandActiveTitlebar2( int v )
    {
      if (!isCommandActiveTitlebar2Immutable())
        mCommandActiveTitlebar2 = v;
    }

    /**
      Get CommandActiveTitlebar2
    */
    int commandActiveTitlebar2() const
    {
      return mCommandActiveTitlebar2;
    }

    /**
      Is CommandActiveTitlebar2 Immutable
    */
    bool isCommandActiveTitlebar2Immutable() const
    {
      return isImmutable( QStringLiteral( "CommandActiveTitlebar2" ) );
    }

    /**
      Get CommandActiveTitlebar2 default value
    */
    int defaultCommandActiveTitlebar2Value() const
    {
        return defaultCommandActiveTitlebar2Value_helper();
    }

    /**
      Set CommandActiveTitlebar3
    */
    void setCommandActiveTitlebar3( int v )
    {
      if (!isCommandActiveTitlebar3Immutable())
        mCommandActiveTitlebar3 = v;
    }

    /**
      Get CommandActiveTitlebar3
    */
    int commandActiveTitlebar3() const
    {
      return mCommandActiveTitlebar3;
    }

    /**
      Is CommandActiveTitlebar3 Immutable
    */
    bool isCommandActiveTitlebar3Immutable() const
    {
      return isImmutable( QStringLiteral( "CommandActiveTitlebar3" ) );
    }

    /**
      Get CommandActiveTitlebar3 default value
    */
    int defaultCommandActiveTitlebar3Value() const
    {
        return defaultCommandActiveTitlebar3Value_helper();
    }

    /**
      Set CommandTitlebarWheel
    */
    void setCommandTitlebarWheel( int v )
    {
      if (!isCommandTitlebarWheelImmutable())
        mCommandTitlebarWheel = v;
    }

    /**
      Get CommandTitlebarWheel
    */
    int commandTitlebarWheel() const
    {
      return mCommandTitlebarWheel;
    }

    /**
      Is CommandTitlebarWheel Immutable
    */
    bool isCommandTitlebarWheelImmutable() const
    {
      return isImmutable( QStringLiteral( "CommandTitlebarWheel" ) );
    }

    /**
      Get CommandTitlebarWheel default value
    */
    int defaultCommandTitlebarWheelValue() const
    {
        return defaultCommandTitlebarWheelValue_helper();
    }

    /**
      Set CommandInactiveTitlebar1
    */
    void setCommandInactiveTitlebar1( int v )
    {
      if (!isCommandInactiveTitlebar1Immutable())
        mCommandInactiveTitlebar1 = v;
    }

    /**
      Get CommandInactiveTitlebar1
    */
    int commandInactiveTitlebar1() const
    {
      return mCommandInactiveTitlebar1;
    }

    /**
      Is CommandInactiveTitlebar1 Immutable
    */
    bool isCommandInactiveTitlebar1Immutable() const
    {
      return isImmutable( QStringLiteral( "CommandInactiveTitlebar1" ) );
    }

    /**
      Get CommandInactiveTitlebar1 default value
    */
    int defaultCommandInactiveTitlebar1Value() const
    {
        return defaultCommandInactiveTitlebar1Value_helper();
    }

    /**
      Set CommandInactiveTitlebar2
    */
    void setCommandInactiveTitlebar2( int v )
    {
      if (!isCommandInactiveTitlebar2Immutable())
        mCommandInactiveTitlebar2 = v;
    }

    /**
      Get CommandInactiveTitlebar2
    */
    int commandInactiveTitlebar2() const
    {
      return mCommandInactiveTitlebar2;
    }

    /**
      Is CommandInactiveTitlebar2 Immutable
    */
    bool isCommandInactiveTitlebar2Immutable() const
    {
      return isImmutable( QStringLiteral( "CommandInactiveTitlebar2" ) );
    }

    /**
      Get CommandInactiveTitlebar2 default value
    */
    int defaultCommandInactiveTitlebar2Value() const
    {
        return defaultCommandInactiveTitlebar2Value_helper();
    }

    /**
      Set CommandInactiveTitlebar3
    */
    void setCommandInactiveTitlebar3( int v )
    {
      if (!isCommandInactiveTitlebar3Immutable())
        mCommandInactiveTitlebar3 = v;
    }

    /**
      Get CommandInactiveTitlebar3
    */
    int commandInactiveTitlebar3() const
    {
      return mCommandInactiveTitlebar3;
    }

    /**
      Is CommandInactiveTitlebar3 Immutable
    */
    bool isCommandInactiveTitlebar3Immutable() const
    {
      return isImmutable( QStringLiteral( "CommandInactiveTitlebar3" ) );
    }

    /**
      Get CommandInactiveTitlebar3 default value
    */
    int defaultCommandInactiveTitlebar3Value() const
    {
        return defaultCommandInactiveTitlebar3Value_helper();
    }

    /**
      Set CommandWindow1
    */
    void setCommandWindow1( int v )
    {
      if (!isCommandWindow1Immutable())
        mCommandWindow1 = v;
    }

    /**
      Get CommandWindow1
    */
    int commandWindow1() const
    {
      return mCommandWindow1;
    }

    /**
      Is CommandWindow1 Immutable
    */
    bool isCommandWindow1Immutable() const
    {
      return isImmutable( QStringLiteral( "CommandWindow1" ) );
    }

    /**
      Get CommandWindow1 default value
    */
    int defaultCommandWindow1Value() const
    {
        return defaultCommandWindow1Value_helper();
    }

    /**
      Set CommandWindow2
    */
    void setCommandWindow2( int v )
    {
      if (!isCommandWindow2Immutable())
        mCommandWindow2 = v;
    }

    /**
      Get CommandWindow2
    */
    int commandWindow2() const
    {
      return mCommandWindow2;
    }

    /**
      Is CommandWindow2 Immutable
    */
    bool isCommandWindow2Immutable() const
    {
      return isImmutable( QStringLiteral( "CommandWindow2" ) );
    }

    /**
      Get CommandWindow2 default value
    */
    int defaultCommandWindow2Value() const
    {
        return defaultCommandWindow2Value_helper();
    }

    /**
      Set CommandWindow3
    */
    void setCommandWindow3( int v )
    {
      if (!isCommandWindow3Immutable())
        mCommandWindow3 = v;
    }

    /**
      Get CommandWindow3
    */
    int commandWindow3() const
    {
      return mCommandWindow3;
    }

    /**
      Is CommandWindow3 Immutable
    */
    bool isCommandWindow3Immutable() const
    {
      return isImmutable( QStringLiteral( "CommandWindow3" ) );
    }

    /**
      Get CommandWindow3 default value
    */
    int defaultCommandWindow3Value() const
    {
        return defaultCommandWindow3Value_helper();
    }

    /**
      Set CommandWindowWheel
    */
    void setCommandWindowWheel( int v )
    {
      if (!isCommandWindowWheelImmutable())
        mCommandWindowWheel = v;
    }

    /**
      Get CommandWindowWheel
    */
    int commandWindowWheel() const
    {
      return mCommandWindowWheel;
    }

    /**
      Is CommandWindowWheel Immutable
    */
    bool isCommandWindowWheelImmutable() const
    {
      return isImmutable( QStringLiteral( "CommandWindowWheel" ) );
    }

    /**
      Get CommandWindowWheel default value
    */
    int defaultCommandWindowWheelValue() const
    {
        return defaultCommandWindowWheelValue_helper();
    }

    /**
      Set CommandAllKey
    */
    void setCommandAllKey( int v )
    {
      if (!isCommandAllKeyImmutable())
        mCommandAllKey = v;
    }

    /**
      Get CommandAllKey
    */
    int commandAllKey() const
    {
      return mCommandAllKey;
    }

    /**
      Is CommandAllKey Immutable
    */
    bool isCommandAllKeyImmutable() const
    {
      return isImmutable( QStringLiteral( "CommandAllKey" ) );
    }

    /**
      Get CommandAllKey default value
    */
    int defaultCommandAllKeyValue() const
    {
        return defaultCommandAllKeyValue_helper();
    }

    /**
      Set CommandAll1
    */
    void setCommandAll1( int v )
    {
      if (!isCommandAll1Immutable())
        mCommandAll1 = v;
    }

    /**
      Get CommandAll1
    */
    int commandAll1() const
    {
      return mCommandAll1;
    }

    /**
      Is CommandAll1 Immutable
    */
    bool isCommandAll1Immutable() const
    {
      return isImmutable( QStringLiteral( "CommandAll1" ) );
    }

    /**
      Get CommandAll1 default value
    */
    int defaultCommandAll1Value() const
    {
        return defaultCommandAll1Value_helper();
    }

    /**
      Set CommandAll2
    */
    void setCommandAll2( int v )
    {
      if (!isCommandAll2Immutable())
        mCommandAll2 = v;
    }

    /**
      Get CommandAll2
    */
    int commandAll2() const
    {
      return mCommandAll2;
    }

    /**
      Is CommandAll2 Immutable
    */
    bool isCommandAll2Immutable() const
    {
      return isImmutable( QStringLiteral( "CommandAll2" ) );
    }

    /**
      Get CommandAll2 default value
    */
    int defaultCommandAll2Value() const
    {
        return defaultCommandAll2Value_helper();
    }

    /**
      Set CommandAll3
    */
    void setCommandAll3( int v )
    {
      if (!isCommandAll3Immutable())
        mCommandAll3 = v;
    }

    /**
      Get CommandAll3
    */
    int commandAll3() const
    {
      return mCommandAll3;
    }

    /**
      Is CommandAll3 Immutable
    */
    bool isCommandAll3Immutable() const
    {
      return isImmutable( QStringLiteral( "CommandAll3" ) );
    }

    /**
      Get CommandAll3 default value
    */
    int defaultCommandAll3Value() const
    {
        return defaultCommandAll3Value_helper();
    }

    /**
      Set CommandAllWheel
    */
    void setCommandAllWheel( int v )
    {
      if (!isCommandAllWheelImmutable())
        mCommandAllWheel = v;
    }

    /**
      Get CommandAllWheel
    */
    int commandAllWheel() const
    {
      return mCommandAllWheel;
    }

    /**
      Is CommandAllWheel Immutable
    */
    bool isCommandAllWheelImmutable() const
    {
      return isImmutable( QStringLiteral( "CommandAllWheel" ) );
    }

    /**
      Get CommandAllWheel default value
    */
    int defaultCommandAllWheelValue() const
    {
        return defaultCommandAllWheelValue_helper();
    }

    /**
      Set DoubleClickBorderToMaximize
    */
    void setDoubleClickBorderToMaximize( bool v )
    {
      if (!isDoubleClickBorderToMaximizeImmutable())
        mDoubleClickBorderToMaximize = v;
    }

    /**
      Get DoubleClickBorderToMaximize
    */
    bool doubleClickBorderToMaximize() const
    {
      return mDoubleClickBorderToMaximize;
    }

    /**
      Is DoubleClickBorderToMaximize Immutable
    */
    bool isDoubleClickBorderToMaximizeImmutable() const
    {
      return isImmutable( QStringLiteral( "DoubleClickBorderToMaximize" ) );
    }

    /**
      Get DoubleClickBorderToMaximize default value
    */
    bool defaultDoubleClickBorderToMaximizeValue() const
    {
        return defaultDoubleClickBorderToMaximizeValue_helper();
    }

  protected:

    // Windows
    int mBorderSnapZone;
    int defaultBorderSnapZoneValue_helper() const;
    int mWindowSnapZone;
    int defaultWindowSnapZoneValue_helper() const;
    int mCenterSnapZone;
    int defaultCenterSnapZoneValue_helper() const;
    bool mSnapOnlyWhenOverlapping;
    bool defaultSnapOnlyWhenOverlappingValue_helper() const;
    bool mShadeHover;
    bool defaultShadeHoverValue_helper() const;
    int mShadeHoverInterval;
    int defaultShadeHoverIntervalValue_helper() const;
    int mPlacement;
    int defaultPlacementValue_helper() const;
    int mActivationDesktopPolicy;
    int defaultActivationDesktopPolicyValue_helper() const;
    int mTitlebarDoubleClickCommand;
    int defaultTitlebarDoubleClickCommandValue_helper() const;
    int mMaximizeButtonLeftClickCommand;
    int defaultMaximizeButtonLeftClickCommandValue_helper() const;
    int mMaximizeButtonMiddleClickCommand;
    int defaultMaximizeButtonMiddleClickCommandValue_helper() const;
    int mMaximizeButtonRightClickCommand;
    int defaultMaximizeButtonRightClickCommandValue_helper() const;
    int mFocusPolicy;
    int defaultFocusPolicyValue_helper() const;
    bool mNextFocusPrefersMouse;
    bool defaultNextFocusPrefersMouseValue_helper() const;
    int mAutoRaiseInterval;
    int defaultAutoRaiseIntervalValue_helper() const;
    int mDelayFocusInterval;
    int defaultDelayFocusIntervalValue_helper() const;
    bool mAutoRaise;
    bool defaultAutoRaiseValue_helper() const;
    bool mClickRaise;
    bool defaultClickRaiseValue_helper() const;
    bool mSeparateScreenFocus;
    bool defaultSeparateScreenFocusValue_helper() const;
    int mFocusStealingPreventionLevel;
    int defaultFocusStealingPreventionLevelValue_helper() const;

    // MouseBindings
    int mCommandActiveTitlebar1;
    int defaultCommandActiveTitlebar1Value_helper() const;
    int mCommandActiveTitlebar2;
    int defaultCommandActiveTitlebar2Value_helper() const;
    int mCommandActiveTitlebar3;
    int defaultCommandActiveTitlebar3Value_helper() const;
    int mCommandTitlebarWheel;
    int defaultCommandTitlebarWheelValue_helper() const;
    int mCommandInactiveTitlebar1;
    int defaultCommandInactiveTitlebar1Value_helper() const;
    int mCommandInactiveTitlebar2;
    int defaultCommandInactiveTitlebar2Value_helper() const;
    int mCommandInactiveTitlebar3;
    int defaultCommandInactiveTitlebar3Value_helper() const;
    int mCommandWindow1;
    int defaultCommandWindow1Value_helper() const;
    int mCommandWindow2;
    int defaultCommandWindow2Value_helper() const;
    int mCommandWindow3;
    int defaultCommandWindow3Value_helper() const;
    int mCommandWindowWheel;
    int defaultCommandWindowWheelValue_helper() const;
    int mCommandAllKey;
    int defaultCommandAllKeyValue_helper() const;
    int mCommandAll1;
    int defaultCommandAll1Value_helper() const;
    int mCommandAll2;
    int defaultCommandAll2Value_helper() const;
    int mCommandAll3;
    int defaultCommandAll3Value_helper() const;
    int mCommandAllWheel;
    int defaultCommandAllWheelValue_helper() const;
    bool mDoubleClickBorderToMaximize;
    bool defaultDoubleClickBorderToMaximizeValue_helper() const;
};

#endif

