/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.KWin.Plugins.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "pluginsadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class PluginsAdaptor
 */

PluginsAdaptor::PluginsAdaptor(KWin::PluginManagerDBusInterface *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

PluginsAdaptor::~PluginsAdaptor()
{
    // destructor
}

QStringList PluginsAdaptor::availablePlugins() const
{
    // get the value of property AvailablePlugins
    return qvariant_cast< QStringList >(parent()->property("AvailablePlugins"));
}

QStringList PluginsAdaptor::loadedPlugins() const
{
    // get the value of property LoadedPlugins
    return qvariant_cast< QStringList >(parent()->property("LoadedPlugins"));
}

bool PluginsAdaptor::LoadPlugin(const QString &name)
{
    // handle method call org.kde.KWin.Plugins.LoadPlugin
    return parent()->LoadPlugin(name);
}

void PluginsAdaptor::UnloadPlugin(const QString &name)
{
    // handle method call org.kde.KWin.Plugins.UnloadPlugin
    parent()->UnloadPlugin(name);
}


#include "moc_pluginsadaptor.cpp"
