// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef KWINDECORATIONDATA_H
#define KWINDECORATIONDATA_H

#include <QObject>

#include "kcmoduledata.h"



class KWinDecorationSettings;


class KWinDecorationData : public KCModuleData
{
    Q_OBJECT

public:
    explicit KWinDecorationData(QObject *parent = nullptr);
    KWinDecorationSettings *settings() const;


private:
    KWinDecorationSettings *m_settings;

};



#endif
