/****************************************************************************
** Meta object code from reading C++ file 'zoom.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kwin-x11-6.7.4/src/plugins/zoom/zoom.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'zoom.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4KWin10ZoomEffectE_t {};
} // unnamed namespace

template <> constexpr inline auto KWin::ZoomEffect::qt_create_metaobjectdata<qt_meta_tag_ZN4KWin10ZoomEffectE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWin::ZoomEffect",
        "zoomIn",
        "",
        "zoomTo",
        "to",
        "zoomOut",
        "actualSize",
        "moveZoomLeft",
        "moveZoomRight",
        "moveZoomUp",
        "moveZoomDown",
        "moveMouseToFocus",
        "moveMouseToCenter",
        "timelineFrameChanged",
        "frame",
        "moveFocus",
        "QPoint",
        "point",
        "slotMouseChanged",
        "QPointF",
        "pos",
        "old",
        "slotWindowAdded",
        "EffectWindow*",
        "w",
        "slotWindowDamaged",
        "slotScreenRemoved",
        "Output*",
        "screen",
        "setTargetZoom",
        "value",
        "zoomFactor",
        "mousePointer",
        "mouseTracking",
        "focusTrackingEnabled",
        "textCaretTrackingEnabled",
        "focusDelay",
        "moveFactor",
        "targetZoom"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'zoomTo'
        QtMocHelpers::SlotData<void(double)>(3, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 4 },
        }}),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'actualSize'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'moveZoomLeft'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'moveZoomRight'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'moveZoomUp'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'moveZoomDown'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'moveMouseToFocus'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'moveMouseToCenter'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'timelineFrameChanged'
        QtMocHelpers::SlotData<void(int)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'moveFocus'
        QtMocHelpers::SlotData<void(const QPoint &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'slotMouseChanged'
        QtMocHelpers::SlotData<void(const QPointF &, const QPointF &)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 19, 21 },
        }}),
        // Slot 'slotWindowAdded'
        QtMocHelpers::SlotData<void(EffectWindow *)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'slotWindowDamaged'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotScreenRemoved'
        QtMocHelpers::SlotData<void(Output *)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Slot 'setTargetZoom'
        QtMocHelpers::SlotData<void(double)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 30 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'zoomFactor'
        QtMocHelpers::PropertyData<qreal>(31, QMetaType::QReal, QMC::DefaultPropertyFlags),
        // property 'mousePointer'
        QtMocHelpers::PropertyData<int>(32, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'mouseTracking'
        QtMocHelpers::PropertyData<int>(33, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'focusTrackingEnabled'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'textCaretTrackingEnabled'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'focusDelay'
        QtMocHelpers::PropertyData<int>(36, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'moveFactor'
        QtMocHelpers::PropertyData<qreal>(37, QMetaType::QReal, QMC::DefaultPropertyFlags),
        // property 'targetZoom'
        QtMocHelpers::PropertyData<qreal>(38, QMetaType::QReal, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ZoomEffect, qt_meta_tag_ZN4KWin10ZoomEffectE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWin::ZoomEffect::staticMetaObject = { {
    QMetaObject::SuperData::link<Effect::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KWin10ZoomEffectE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KWin10ZoomEffectE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4KWin10ZoomEffectE_t>.metaTypes,
    nullptr
} };

void KWin::ZoomEffect::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ZoomEffect *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->zoomIn(); break;
        case 1: _t->zoomTo((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 2: _t->zoomOut(); break;
        case 3: _t->actualSize(); break;
        case 4: _t->moveZoomLeft(); break;
        case 5: _t->moveZoomRight(); break;
        case 6: _t->moveZoomUp(); break;
        case 7: _t->moveZoomDown(); break;
        case 8: _t->moveMouseToFocus(); break;
        case 9: _t->moveMouseToCenter(); break;
        case 10: _t->timelineFrameChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->moveFocus((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 12: _t->slotMouseChanged((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2]))); break;
        case 13: _t->slotWindowAdded((*reinterpret_cast<std::add_pointer_t<EffectWindow*>>(_a[1]))); break;
        case 14: _t->slotWindowDamaged(); break;
        case 15: _t->slotScreenRemoved((*reinterpret_cast<std::add_pointer_t<Output*>>(_a[1]))); break;
        case 16: _t->setTargetZoom((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qreal*>(_v) = _t->configuredZoomFactor(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->configuredMousePointer(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->configuredMouseTracking(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isFocusTrackingEnabled(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isTextCaretTrackingEnabled(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->configuredFocusDelay(); break;
        case 6: *reinterpret_cast<qreal*>(_v) = _t->configuredMoveFactor(); break;
        case 7: *reinterpret_cast<qreal*>(_v) = _t->targetZoom(); break;
        default: break;
        }
    }
}

const QMetaObject *KWin::ZoomEffect::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWin::ZoomEffect::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KWin10ZoomEffectE_t>.strings))
        return static_cast<void*>(this);
    return Effect::qt_metacast(_clname);
}

int KWin::ZoomEffect::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Effect::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
