/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.KWin.NightLight.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "nightlightadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class NightLightAdaptor
 */

NightLightAdaptor::NightLightAdaptor(KWin::NightLightDBusInterface *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

NightLightAdaptor::~NightLightAdaptor()
{
    // destructor
}

bool NightLightAdaptor::available() const
{
    // get the value of property available
    return qvariant_cast< bool >(parent()->property("available"));
}

uint NightLightAdaptor::currentTemperature() const
{
    // get the value of property currentTemperature
    return qvariant_cast< uint >(parent()->property("currentTemperature"));
}

bool NightLightAdaptor::daylight() const
{
    // get the value of property daylight
    return qvariant_cast< bool >(parent()->property("daylight"));
}

bool NightLightAdaptor::enabled() const
{
    // get the value of property enabled
    return qvariant_cast< bool >(parent()->property("enabled"));
}

bool NightLightAdaptor::inhibited() const
{
    // get the value of property inhibited
    return qvariant_cast< bool >(parent()->property("inhibited"));
}

uint NightLightAdaptor::mode() const
{
    // get the value of property mode
    return qvariant_cast< uint >(parent()->property("mode"));
}

qulonglong NightLightAdaptor::previousTransitionDateTime() const
{
    // get the value of property previousTransitionDateTime
    return qvariant_cast< qulonglong >(parent()->property("previousTransitionDateTime"));
}

uint NightLightAdaptor::previousTransitionDuration() const
{
    // get the value of property previousTransitionDuration
    return qvariant_cast< uint >(parent()->property("previousTransitionDuration"));
}

bool NightLightAdaptor::running() const
{
    // get the value of property running
    return qvariant_cast< bool >(parent()->property("running"));
}

qulonglong NightLightAdaptor::scheduledTransitionDateTime() const
{
    // get the value of property scheduledTransitionDateTime
    return qvariant_cast< qulonglong >(parent()->property("scheduledTransitionDateTime"));
}

uint NightLightAdaptor::scheduledTransitionDuration() const
{
    // get the value of property scheduledTransitionDuration
    return qvariant_cast< uint >(parent()->property("scheduledTransitionDuration"));
}

uint NightLightAdaptor::targetTemperature() const
{
    // get the value of property targetTemperature
    return qvariant_cast< uint >(parent()->property("targetTemperature"));
}

uint NightLightAdaptor::inhibit()
{
    // handle method call org.kde.KWin.NightLight.inhibit
    return parent()->inhibit();
}

void NightLightAdaptor::preview(uint temperature)
{
    // handle method call org.kde.KWin.NightLight.preview
    parent()->preview(temperature);
}

void NightLightAdaptor::stopPreview()
{
    // handle method call org.kde.KWin.NightLight.stopPreview
    parent()->stopPreview();
}

void NightLightAdaptor::uninhibit(uint cookie)
{
    // handle method call org.kde.KWin.NightLight.uninhibit
    parent()->uninhibit(cookie);
}


#include "moc_nightlightadaptor.cpp"
