/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.KWin.ScreenShot2.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef SCREENSHOT2ADAPTOR_H
#define SCREENSHOT2ADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "screenshotdbusinterface2.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.KWin.ScreenShot2
 */
class ScreenShot2Adaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.KWin.ScreenShot2")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.KWin.ScreenShot2\">\n"
"    <property access=\"read\" type=\"u\" name=\"Version\"/>\n"
"    <method name=\"CaptureWindow\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"handle\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In1\"/>\n"
"      <arg direction=\"in\" type=\"a{sv}\" name=\"options\"/>\n"
"      <arg direction=\"in\" type=\"h\" name=\"pipe\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <arg direction=\"out\" type=\"a{sv}\" name=\"results\"/>\n"
"    </method>\n"
"    <method name=\"CaptureActiveWindow\">\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <arg direction=\"in\" type=\"a{sv}\" name=\"options\"/>\n"
"      <arg direction=\"in\" type=\"h\" name=\"pipe\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <arg direction=\"out\" type=\"a{sv}\" name=\"results\"/>\n"
"    </method>\n"
"    <method name=\"CaptureArea\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"x\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"y\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"width\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"height\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In4\"/>\n"
"      <arg direction=\"in\" type=\"a{sv}\" name=\"options\"/>\n"
"      <arg direction=\"in\" type=\"h\" name=\"pipe\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <arg direction=\"out\" type=\"a{sv}\" name=\"results\"/>\n"
"    </method>\n"
"    <method name=\"CaptureScreen\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In1\"/>\n"
"      <arg direction=\"in\" type=\"a{sv}\" name=\"options\"/>\n"
"      <arg direction=\"in\" type=\"h\" name=\"pipe\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <arg direction=\"out\" type=\"a{sv}\" name=\"results\"/>\n"
"    </method>\n"
"    <method name=\"CaptureActiveScreen\">\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <arg direction=\"in\" type=\"a{sv}\" name=\"options\"/>\n"
"      <arg direction=\"in\" type=\"h\" name=\"pipe\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <arg direction=\"out\" type=\"a{sv}\" name=\"results\"/>\n"
"    </method>\n"
"    <method name=\"CaptureInteractive\">\n"
"      <arg direction=\"in\" type=\"u\" name=\"kind\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In1\"/>\n"
"      <arg direction=\"in\" type=\"a{sv}\" name=\"options\"/>\n"
"      <arg direction=\"in\" type=\"h\" name=\"pipe\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <arg direction=\"out\" type=\"a{sv}\" name=\"results\"/>\n"
"    </method>\n"
"    <method name=\"CaptureWorkspace\">\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <arg direction=\"in\" type=\"a{sv}\" name=\"options\"/>\n"
"      <arg direction=\"in\" type=\"h\" name=\"pipe\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <arg direction=\"out\" type=\"a{sv}\" name=\"results\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    ScreenShot2Adaptor(KWin::ScreenShotDBusInterface2 *parent);
    ~ScreenShot2Adaptor() override;

    inline KWin::ScreenShotDBusInterface2 *parent() const
    { return static_cast<KWin::ScreenShotDBusInterface2 *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(uint Version READ version)
    uint version() const;

public Q_SLOTS: // METHODS
    QVariantMap CaptureActiveScreen(const QVariantMap &options, const QDBusUnixFileDescriptor &pipe);
    QVariantMap CaptureActiveWindow(const QVariantMap &options, const QDBusUnixFileDescriptor &pipe);
    QVariantMap CaptureArea(int x, int y, uint width, uint height, const QVariantMap &options, const QDBusUnixFileDescriptor &pipe);
    QVariantMap CaptureInteractive(uint kind, const QVariantMap &options, const QDBusUnixFileDescriptor &pipe);
    QVariantMap CaptureScreen(const QString &name, const QVariantMap &options, const QDBusUnixFileDescriptor &pipe);
    QVariantMap CaptureWindow(const QString &handle, const QVariantMap &options, const QDBusUnixFileDescriptor &pipe);
    QVariantMap CaptureWorkspace(const QVariantMap &options, const QDBusUnixFileDescriptor &pipe);
Q_SIGNALS: // SIGNALS
};

#endif
